from setuptools import setup, find_packages

setup(
    name='waylake_utils',
    version='0.1.5',
    packages=find_packages(),
    description='Custom logging utility',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='waylake',
    author_email='plmokn7034soo@icloud.com',
)
